searchData={"items":[{"type":"module","title":"ExWeatherkit","doc":"ExWeatherkit is an Apple WeatherKit REST API client for Elixir","ref":"ExWeatherkit.html"},{"type":"function","title":"ExWeatherkit.current_weather/4","doc":"Get current weather for a latitude and longitude","ref":"ExWeatherkit.html#current_weather/4"},{"type":"function","title":"Parameters - ExWeatherkit.current_weather/4","doc":"- lat: The latitude of the desired location\n  - lng: The longitude of the desired location\n  - lang: The language tag to use for localizing responses\n  - tz: The name of the timezone to use for rolling up weather forecasts into daily forecasts","ref":"ExWeatherkit.html#current_weather/4-parameters"},{"type":"function","title":"Example: - ExWeatherkit.current_weather/4","doc":"iex> ExWeatherkit.current_weather(39.183608, -96.571669)","ref":"ExWeatherkit.html#current_weather/4-example"},{"type":"function","title":"ExWeatherkit.forecast_daily/4","doc":"Get daily forecast for a latitude and longitude","ref":"ExWeatherkit.html#forecast_daily/4"},{"type":"function","title":"Parameters - ExWeatherkit.forecast_daily/4","doc":"- lat: The latitude of the desired location\n  - lng: The longitude of the desired location\n  - lang: The language tag to use for localizing responses\n  - tz: The name of the timezone to use for rolling up weather forecasts into daily forecasts","ref":"ExWeatherkit.html#forecast_daily/4-parameters"},{"type":"function","title":"Example: - ExWeatherkit.forecast_daily/4","doc":"iex> ExWeatherkit.forecast_daily(39.183608, -96.571669)","ref":"ExWeatherkit.html#forecast_daily/4-example"},{"type":"function","title":"ExWeatherkit.forecast_hourly/4","doc":"Get hourly forecast for a latitude and longitude","ref":"ExWeatherkit.html#forecast_hourly/4"},{"type":"function","title":"Parameters - ExWeatherkit.forecast_hourly/4","doc":"- lat: The latitude of the desired location\n  - lng: The longitude of the desired location\n  - lang: The language tag to use for localizing responses\n  - tz: The name of the timezone to use for rolling up weather forecasts into daily forecasts","ref":"ExWeatherkit.html#forecast_hourly/4-parameters"},{"type":"function","title":"Example: - ExWeatherkit.forecast_hourly/4","doc":"iex> ExWeatherkit.forecast_hourly(39.183608, -96.571669)","ref":"ExWeatherkit.html#forecast_hourly/4-example"},{"type":"function","title":"ExWeatherkit.forecast_next_hour/4","doc":"Get next hour forecast for a latitude and longitude","ref":"ExWeatherkit.html#forecast_next_hour/4"},{"type":"function","title":"Parameters - ExWeatherkit.forecast_next_hour/4","doc":"- lat: The latitude of the desired location\n  - lng: The longitude of the desired location\n  - lang: The language tag to use for localizing responses\n  - tz: The name of the timezone to use for rolling up weather forecasts into daily forecasts","ref":"ExWeatherkit.html#forecast_next_hour/4-parameters"},{"type":"function","title":"Example: - ExWeatherkit.forecast_next_hour/4","doc":"iex> ExWeatherkit.forecast_next_hour(39.183608, -96.571669)","ref":"ExWeatherkit.html#forecast_next_hour/4-example"},{"type":"function","title":"ExWeatherkit.weather_alerts/5","doc":"Get weather alerts for a latitude and longitude","ref":"ExWeatherkit.html#weather_alerts/5"},{"type":"function","title":"Parameters - ExWeatherkit.weather_alerts/5","doc":"- lat: The latitude of the desired location\n  - lng: The longitude of the desired location\n  - lang: The language tag to use for localizing responses\n  - tz: The name of the timezone to use for rolling up weather forecasts into daily forecasts\n  - country_code: The ISO Alpha-2 country code for the requested location","ref":"ExWeatherkit.html#weather_alerts/5-parameters"},{"type":"function","title":"Example: - ExWeatherkit.weather_alerts/5","doc":"iex> ExWeatherkit.weather_alerts(39.183608, -96.571669)","ref":"ExWeatherkit.html#weather_alerts/5-example"},{"type":"function","title":"ExWeatherkit.weather_multi/6","doc":"Get multiple weather data sets for a latitude and longitude","ref":"ExWeatherkit.html#weather_multi/6"},{"type":"function","title":"Parameters - ExWeatherkit.weather_multi/6","doc":"- lat: The latitude of the desired location\n  - lng: The longitude of the desired location\n  - lang: The language tag to use for localizing responses\n  - tz: The name of the timezone to use for rolling up weather forecasts into daily forecasts\n  - data_sets: A list of data sets to include in the response, possible values: currentWeather, forecastDaily, forecastHourly, forecastNextHour, weatherAlerts\n  - country_code: The ISO Alpha-2 country code of the requested location","ref":"ExWeatherkit.html#weather_multi/6-parameters"},{"type":"function","title":"Example: - ExWeatherkit.weather_multi/6","doc":"iex> ExWeatherkit.weather_multi(39.183608, -96.571669, [\"currentWeather\", \"forecastDaily\"])","ref":"ExWeatherkit.html#weather_multi/6-example"},{"type":"extras","title":"ExWeatherkit","doc":"# ExWeatherkit\n\n[![hex.pm](https://img.shields.io/hexpm/v/ex_weatherkit.svg)](https://hex.pm/packages/ex_weatherkit)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ex_weatherkit/)\n[![hex.pm](https://img.shields.io/hexpm/dt/ex_weatherkit.svg)](https://hex.pm/packages/ex_weatherkit)\n[![hex.pm](https://img.shields.io/hexpm/l/ex_weatherkit.svg)](https://hex.pm/packages/ex_weatherkit)\n\nAn Apple WeatherKit REST API client for Elixir","ref":"readme.html"},{"type":"extras","title":"Installation - ExWeatherkit","doc":"The package can be installed by adding `ex_weatherkit` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:ex_weatherkit, \"~> 0.1.2\"}\n  ]\nend\n```\n\nYou will need an Apple Developer Program membership to [create a private key for WeatherKit access and a Service ID](https://developer.apple.com/documentation/weatherkitrestapi/request_authentication_for_weatherkit_rest_api) to access the WeatherKit REST API.\n\nOnce you have those along with your ADP membership Team ID, add the required values to your config file (preferable to load values from env variables)\n\n```elixir\nconfig :ex_weatherkit,\n  key_id: \"ABCDEF1234\"\n  service_id: \"com.example.weatherkitclient\"\n  team_id: \"ZYXWVU8765\"\n  private_key: \"\"\"-----BEGIN PRIVATE KEY-----....\"\"\"\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ExWeatherkit","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Current weather - ExWeatherkit","doc":"```elixir\n{:ok, weather, _status} = ExWeatherkit.current_weather(39.183608, -96.571669)\n\n{:ok,\n %{\n   \"currentWeather\" => %{\n     \"asOf\" => \"2023-09-17T13:28:23Z\",\n     \"cloudCover\" => 0.13,\n     \"cloudCoverHighAltPct\" => 0.0,\n     \"cloudCoverLowAltPct\" => 0.2,\n     \"cloudCoverMidAltPct\" => 0.0,\n     \"conditionCode\" => \"MostlyClear\",\n     \"daylight\" => true,\n     \"humidity\" => 0.83,\n     \"metadata\" => %{\n       \"attributionURL\" => \"https://developer.apple.com/weatherkit/data-source-attribution/\",\n       \"expireTime\" => \"2023-09-17T13:33:23Z\",\n       \"latitude\" => 39.184,\n       \"longitude\" => -96.572,\n       \"readTime\" => \"2023-09-17T13:28:23Z\",\n       \"reportedTime\" => \"2023-09-17T12:13:09Z\",\n       \"units\" => \"m\",\n       \"version\" => 1\n     },\n     \"name\" => \"CurrentWeather\",\n     \"precipitationIntensity\" => 0.0,\n     \"pressure\" => 1019.47,\n     \"pressureTrend\" => \"rising\",\n     \"temperature\" => 13.49,\n     \"temperatureApparent\" => 13.08,\n     \"temperatureDewPoint\" => 10.73,\n     \"uvIndex\" => 0,\n     \"visibility\" => 23615.8,\n     \"windDirection\" => 18,\n     \"windGust\" => 10.27,\n     \"windSpeed\" => 5.1\n   }\n }, 200}\n```","ref":"readme.html#current-weather"},{"type":"extras","title":"Daily forecast - ExWeatherkit","doc":"```elixir\n{:ok, weather, _status} = ExWeatherkit.forecast_daily(39.183608, -96.571669)\n```","ref":"readme.html#daily-forecast"},{"type":"extras","title":"Hourly forecast - ExWeatherkit","doc":"```elixir\n{:ok, weather, _status} = ExWeatherkit.forecast_hourly(39.183608, -96.571669)\n```","ref":"readme.html#hourly-forecast"},{"type":"extras","title":"Next hour forecast - ExWeatherkit","doc":"```elixir\n{:ok, weather, _status} = ExWeatherkit.forecast_next_hour(39.183608, -96.571669)\n```","ref":"readme.html#next-hour-forecast"},{"type":"extras","title":"Weather alerts - ExWeatherkit","doc":"```elixir\n{:ok, weather, _status} = ExWeatherkit.weather_alerts(39.183608, -96.571669)\n```","ref":"readme.html#weather-alerts"},{"type":"extras","title":"Multiple weather datasets - ExWeatherkit","doc":"```elixir\n{:ok, weather, _status} = ExWeatherkit.weather_multi(39.183608, -96.571669, [\"currentWeather\", \"forecastDaily\"])\n```","ref":"readme.html#multiple-weather-datasets"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2023 Bryce Johnston\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}